from django.conf import settings


if getattr(settings, 'SEEKER_OPENSEARCH', False):
    import opensearch_dsl as dsl
    from opensearch_dsl import A, Q, Search
    from opensearch_dsl.aggs import Terms
    from opensearch_dsl.connections import connections
    from opensearch_dsl.field import Object
    from opensearch_dsl.response import Response
    from opensearch_dsl.utils import AttrList
    from opensearchpy.exceptions import AuthorizationException, NotFoundError, TransportError
    from opensearchpy.helpers import bulk, scan
else:
    import elasticsearch_dsl as dsl
    from elasticsearch.exceptions import AuthorizationException, NotFoundError, TransportError
    from elasticsearch.helpers import bulk, scan
    from elasticsearch_dsl import A, Q, Search
    from elasticsearch_dsl.aggs import Terms
    from elasticsearch_dsl.connections import connections
    from elasticsearch_dsl.field import Object
    from elasticsearch_dsl.response import Response
    from elasticsearch_dsl.utils import AttrList



import json
from optparse import make_option

from django.apps import apps
from django.core.management.base import BaseCommand, CommandError
from seeker.dsl import bulk, connections


class Command(BaseCommand):
    args = '<app1 app2 ...>'
    option_list = BaseCommand.option_list + (
        make_option('--filename', '-f',
                    dest='filename',
                    default=None,
                    help='The file to load index data from',
        ),
        make_option('--index',
                    dest='index',
                    default=None,
                    help='Index to load data into',
        ),
    )

    def handle(self, *args, **options):
        if not options['filename']:
            raise CommandError('Please specify a file (-f) to read data from')

        refresh_indices = set()

        def get_actions():
            for data in json.load(open(options['filename'], 'rb')):
                if options['index']:
                    data['_index'] = options['index']
                refresh_indices.add(data['_index'])
                yield data

        connection = connections.get_connection()
        bulk(connection, get_actions())

        for index in refresh_indices:
            connection.indices.refresh(index=index)
